# Plugin for TWiki Enterprise Collaboration Platform, http://TWiki.org/
#
# Copyright (C) 2000-2003 Andrea Sterbini, a.sterbini@flashnet.it
# Copyright (C) 2001-2013 Peter Thoeny, peter[at]thoeny.org
# Copyright (C) 2001-2013 TWiki Contributors.
# All Rights Reserved. TWiki Contributors are listed in the AUTHORS
# file in the root of this distribution.
# NOTE: Please extend that file, not this notice.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version. For
# more details read LICENSE in the root of this distribution.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
# For licensing info read LICENSE file in the TWiki root.

# Always use strict to enforce variable scoping
use strict;

# change the package name and $pluginName!!!
package TWiki::Plugins::DeleteRevisionsPlugin;

# Name of this Plugin, only used in this module
our $pluginName = 'DeleteRevisionsPlugin';

require TWiki::Func;    # The plugins API
require TWiki::Plugins; # For the API version
require TWiki::Contrib::DeleteRevisionsAddOn;

# $VERSION is referred to by TWiki, and is the only global variable that
# *must* exist in this package. It should always be Rev enclosed in dollar
# signs so that TWiki can determine the checked-in status of the plugin.
# It is used by the build automation tools, so you should leave it alone.
our $VERSION = '$Rev: 25093 (2013-02-16) $';

# This is a free-form string you can use to "name" your own plugin version.
# It is *not* used by the build automation tools, but is reported as part
# of the version number in PLUGINDESCRIPTIONS. Add a release date in ISO
# format (preferred) or a release number such as '1.3'.
our $RELEASE = '2013-02-16';

# One line description, is shown in the %SYSTEMWEB%.TextFormattingRules topic:
our $SHORTDESCRIPTION = 'Plugin to determine if the link for deleting revisions should be shown in oopsmore.tmpl';

# You must set $NO_PREFS_IN_TOPIC to 0 if you want your plugin to use preferences
# stored in the plugin topic. This default is required for compatibility with
# older plugins, but imposes a significant performance penalty, and
# is not recommended. Instead, use $TWiki::cfg entries set in LocalSite.cfg, or
# if you want the users to be able to change settings, then use standard TWiki
# preferences that can be defined in your Main.TWikiPreferences and overridden
# at the web and topic level.
our $NO_PREFS_IN_TOPIC = 1;

# Define other global package variables
our $debug;

sub initPlugin {
    my( $topic, $web, $user, $installWeb ) = @_;

    # check for Plugins.pm versions
    if( $TWiki::Plugins::VERSION < 1.1 ) {
        TWiki::Func::writeWarning( "Version mismatch between $pluginName and Plugins.pm" );
        return 0;
    }

    # If we are in the "More actions" page (/bin/oops/Web/Topic for some reason), we check if the user is allowed to delete revisions for this topic. If he is, we set a preference.
    my $context = TWiki::Func::getContext();
    if (defined $context->{oops} && TWiki::Contrib::DeleteRevisionsAddOn::canDeleteRevisions($TWiki::Plugins::SESSION, $topic, $web, TWiki::Func::getCanonicalUserID($user))) {
        if (defined ($ENV{'HTTP_REFERER'}) && $ENV{'HTTP_REFERER'} =~ m/\/bin\/(?<action>[a-z0-9]+)\/$web\/$topic/i) {
            TWiki::Func::setPreferencesValue('DELREF_REDIRECT_TO', $+{action});
        }
    
        TWiki::Func::setPreferencesValue('CAN_DELETE_REVISIONS', 'YES!');
    }

    # Plugin correctly initialized
    return 1;
}

1;
